@@ -9,21 +9,13 @@
 #' @examples
 #'   get_average_nltt_matrix(c(ape::rcoal(10), ape::rcoal(20)))
 #'
-#' @author Richel Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @export
 get_average_nltt_matrix <- function(
   phylogenies,
-  dt = 0.001) {
-  if (length(phylogenies) < 1) {
-    stop("there must be at least one phylogeny supplied")
-  }
-  if (class(phylogenies) != "multiPhylo" && class(phylogenies) != "list") {
-    stop("phylogenies must be of class 'multiPhylo' or 'list'")
-  }
-  if (!inherits(phylogenies[[1]], "phylo")) {
-    # Stop imposed by ape::ltt.plot.coords
-    stop("phylogenies must be of type phylo")
-  }
+  dt = 0.001
+) {
+  nLTT::check_phylogenies(phylogenies)
   if (dt <= 0.0 || dt >= 1.0) {
     stop("dt must be between (not including) zero and one")
   }
