@@ -1,8 +1,6 @@
 #' Get the average nLTT from a collection of phylogenies
 #'
-#' @param phylogenies the phylogenies, where the phylogenies are of type 'phylo'
-#' @param dt The timestep resolution,
-#'   where 1/dt is the number of points evaluated
+#' @inheritParams default_params_doc
 #' @param plot_nltts Also plot each nLLT line
 #' @param xlab Label on the x axis
 #' @param ylab Label on the y axis
@@ -13,8 +11,7 @@
 #' @examples
 #'   nltts_plot(c(ape::rcoal(10), ape::rcoal(10)))
 #'   nltts_plot(c(ape::rcoal(10), ape::rcoal(20)), dt = 0.1)
-#'
-#' @author Richel Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @export
 nltts_plot <- function(
   phylogenies,
@@ -25,16 +22,7 @@ nltts_plot <- function(
   replot = FALSE,
   ...
 ) {
-  if (length(phylogenies) < 1) {
-    stop("there must be at least one phylogeny supplied")
-  }
-  if (class(phylogenies) != "multiPhylo" && class(phylogenies) != "list") {
-    stop("phylogenies must be of class 'multiPhylo' or 'list'")
-  }
-  if (!inherits(phylogenies[[1]], "phylo")) {
-    # Stop imposed by ape::ltt.plot.coords
-    stop("phylogenies must be of type phylo")
-  }
+  nLTT::check_phylogenies(phylogenies)
   if (dt <= 0.0 || dt >= 1.0) {
     stop("dt must be between (not including) zero and one")
   }
